mathtools.Infinity
==================

.. abjad-lineage:: abjad.tools.mathtools.Infinity.Infinity.Infinity

.. autoclass:: abjad.tools.mathtools.Infinity.Infinity.Infinity
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.Infinity.Infinity.Infinity.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.Infinity.__repr__
   :noindex:
